@@ -11,12 +11,14 @@ var group__rate__control =
     [ "av1_first_pass", "group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d", null ],
     [ "av1_gop_setup_structure", "group__rate__control.html#ga6853e4fcc63f2f54ae429e27286827ae", null ],
     [ "av1_gop_bit_allocation", "group__rate__control.html#gac12d62af325ff26685a28bebb0137a65", null ],
-    [ "av1_get_second_pass_params", "group__rate__control.html#gaa5b125ad159f53b6ee5423900e479c0b", null ],
+    [ "av1_gop_check_forward_keyframe", "group__rate__control.html#gac1743a047b06169064f57c74288d7537", null ],
+    [ "av1_gop_is_second_arf", "group__rate__control.html#ga50283a647b83308a9a7c02b74a980ac1", null ],
+    [ "av1_get_second_pass_params", "group__rate__control.html#ga2c30e6d5b7f0c87a7aa61cabace6905c", null ],
     [ "av1_twopass_postencode_update", "group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544", null ],
     [ "get_twopass_worst_quality", "group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f", null ],
     [ "calculate_total_gf_group_bits", "group__rate__control.html#gaa1b79c4de593c5ddccf4f0384d51e901", null ],
     [ "get_rate_correction_factor", "group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f", null ],
-    [ "set_rate_correction_factor", "group__rate__control.html#gae9e6431ebd75ca58a1e526f91cc0cea8", null ],
+    [ "set_rate_correction_factor", "group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f", null ],
     [ "find_closest_qindex_by_rate", "group__rate__control.html#ga8cc1e01e3fb0a620ea3a7ab53d94eb6e", null ],
     [ "rc_pick_q_and_bounds_no_stats_cbr", "group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89", null ],
     [ "rc_pick_q_and_bounds_no_stats", "group__rate__control.html#gabfb0989110479fa704a1b245a4c4c1cf", null ],
@@ -26,7 +28,7 @@ var group__rate__control =
     [ "rc_scene_detection_onepass_rt", "group__rate__control.html#ga06eb20a95903f261d8e9a86f6a359927", null ],
     [ "set_gf_interval_update_onepass_rt", "group__rate__control.html#ga7778c29e995a78b2521fe4f0bab0c9c1", null ],
     [ "dynamic_resize_one_pass_cbr", "group__rate__control.html#ga4770b9bf9d2f350267d57a8dcc48d0a2", null ],
-    [ "av1_rc_update_rate_correction_factors", "group__rate__control.html#gaf4845f52af8f34c200706e1c3e14614f", null ],
+    [ "av1_rc_update_rate_correction_factors", "group__rate__control.html#ga23765f9ab795ae26c6949163ceb9a4e3", null ],
     [ "av1_rc_pick_q_and_bounds", "group__rate__control.html#gaabc94f144903517a3d4aff8f65da1638", null ],
     [ "av1_rc_regulate_q", "group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845", null ],
     [ "av1_calc_pframe_target_size_one_pass_vbr", "group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2", null ],
