@@ -1,6 +1,5 @@
 var NAVTREEINDEX1 =
 {
-"encoder_guide.html#architecture_entropy_coef":[8,14,1],
 "encoder_guide.html#architecture_entropy_coef_coding":[8,14,1,0,1],
 "encoder_guide.html#architecture_entropy_coef_context":[8,14,1,0,2],
 "encoder_guide.html#architecture_entropy_coef_cost":[8,14,1,1,0],
@@ -39,8 +38,8 @@ var NAVTREEINDEX1 =
 "example_twopass_encoder.html":[9,6],
 "files.html":[14,0],
 "firstpass_8h_source.html":[14,0,2,2,6],
-"functions.html":[13,1,0],
 "functions.html":[13,1,0,0],
+"functions.html":[13,1,0],
 "functions_b.html":[13,1,0,1],
 "functions_c.html":[13,1,0,2],
 "functions_d.html":[13,1,0,3],
@@ -62,8 +61,8 @@ var NAVTREEINDEX1 =
 "functions_t.html":[13,1,0,19],
 "functions_u.html":[13,1,0,20],
 "functions_v.html":[13,1,0,21],
-"functions_vars.html":[13,1,1,0],
 "functions_vars.html":[13,1,1],
+"functions_vars.html":[13,1,1,0],
 "functions_vars_b.html":[13,1,1,1],
 "functions_vars_c.html":[13,1,1,2],
 "functions_vars_d.html":[13,1,1,3],
@@ -93,30 +92,33 @@ var NAVTREEINDEX1 =
 "functions_x.html":[13,1,0,23],
 "functions_y.html":[13,1,0,24],
 "functions_z.html":[13,1,0,25],
-"globals.html":[14,1,0],
 "globals.html":[14,1,0,0],
+"globals.html":[14,1,0],
 "globals_c.html":[14,1,0,1],
 "globals_defs.html":[14,1,6],
+"globals_e.html":[14,1,0,2],
 "globals_enum.html":[14,1,4],
-"globals_eval.html":[14,1,5,0],
 "globals_eval.html":[14,1,5],
+"globals_eval.html":[14,1,5,0],
 "globals_eval_c.html":[14,1,5,1],
-"globals_eval_i.html":[14,1,5,2],
-"globals_eval_q.html":[14,1,5,3],
-"globals_eval_r.html":[14,1,5,4],
-"globals_eval_s.html":[14,1,5,5],
-"globals_eval_t.html":[14,1,5,6],
-"globals_f.html":[14,1,0,2],
+"globals_eval_e.html":[14,1,5,2],
+"globals_eval_i.html":[14,1,5,3],
+"globals_eval_p.html":[14,1,5,4],
+"globals_eval_q.html":[14,1,5,5],
+"globals_eval_r.html":[14,1,5,6],
+"globals_eval_s.html":[14,1,5,7],
+"globals_eval_t.html":[14,1,5,8],
+"globals_f.html":[14,1,0,3],
 "globals_func.html":[14,1,1],
-"globals_h.html":[14,1,0,3],
-"globals_i.html":[14,1,0,4],
-"globals_m.html":[14,1,0,5],
-"globals_o.html":[14,1,0,6],
-"globals_p.html":[14,1,0,7],
-"globals_q.html":[14,1,0,8],
-"globals_r.html":[14,1,0,9],
-"globals_s.html":[14,1,0,10],
-"globals_t.html":[14,1,0,11],
+"globals_h.html":[14,1,0,4],
+"globals_i.html":[14,1,0,5],
+"globals_m.html":[14,1,0,6],
+"globals_o.html":[14,1,0,7],
+"globals_p.html":[14,1,0,8],
+"globals_q.html":[14,1,0,9],
+"globals_r.html":[14,1,0,10],
+"globals_s.html":[14,1,0,11],
+"globals_t.html":[14,1,0,12],
 "globals_type.html":[14,1,3],
 "globals_vars.html":[14,1,2],
 "gop__structure_8h_source.html":[14,0,2,2,7],
@@ -199,7 +201,8 @@ var NAVTREEINDEX1 =
 "group__aom__encoder.html#ga00f4961195d6d1d53c045d9675bb4d78":[12,1,0,0,55],
 "group__aom__encoder.html#ga0713a9137d099e441bd6b7ed10be1b0d":[12,1,0,0,57],
 "group__aom__encoder.html#ga0f19205f8fb08e9d9aa49403428ff33b":[12,1,0,0,45],
-"group__aom__encoder.html#ga18350b1c0642494e2b1a970104b2e8b9":[12,1,0,0,88],
+"group__aom__encoder.html#ga1041d05f74205cf3cfbe4d05a1f99345":[12,1,0,0,87],
+"group__aom__encoder.html#ga18350b1c0642494e2b1a970104b2e8b9":[12,1,0,0,89],
 "group__aom__encoder.html#ga1a11077df0999ffba72a6fbfc8fe3331":[12,1,0,0,65],
 "group__aom__encoder.html#ga23f13860556f8879c2cef2565b8182a8":[12,1,0,0,30],
 "group__aom__encoder.html#ga241e62c4cf0d5f31f56e6be63df8e566":[12,1,0,0,80],
@@ -222,7 +225,7 @@ var NAVTREEINDEX1 =
 "group__aom__encoder.html#ga6ee5804fef84710679f46bb77895aa90":[12,1,0,0,28],
 "group__aom__encoder.html#ga7543b396ff2eef24d90b8edd094a9148":[12,1,0,0,79],
 "group__aom__encoder.html#ga758649aa6cd9fefb15ad888489884a38":[12,1,0,0,36],
-"group__aom__encoder.html#ga77adf3b7884b3619a4c5cbc236fe9de5":[12,1,0,0,87],
+"group__aom__encoder.html#ga77adf3b7884b3619a4c5cbc236fe9de5":[12,1,0,0,88],
 "group__aom__encoder.html#ga790f05ad7832f2614a13fd60bd3430fe":[12,1,0,0,59],
 "group__aom__encoder.html#ga7a55a46970c074b761319c5c46d87b6e":[12,1,0,0,38],
 "group__aom__encoder.html#ga801f5eb2cb93da19a2f347ae7a44166a":[12,1,0,0,84],
@@ -246,8 +249,5 @@ var NAVTREEINDEX1 =
 "group__aom__encoder.html#gaca3421fd8424ed3ab48704748a12c9d1":[12,1,0,0,51],
 "group__aom__encoder.html#gacd5a13523326346771b2cf343cea96be":[12,1,0,0,75],
 "group__aom__encoder.html#gacfd479b87a0dc8cb0602268f9dca37ce":[12,1,0,0,60],
-"group__aom__encoder.html#gad04799a74215e1b9609f7ccd1766f8c9":[12,1,0,0,37],
-"group__aom__encoder.html#gad09f5b034137ba0981dd5f2dc075b27f":[12,1,0,0,56],
-"group__aom__encoder.html#gad69c1d6aa10530991eeb1a3f0a818cba":[12,1,0,0,85],
-"group__aom__encoder.html#gadb34e02e5b029504370f99a886371710":[12,1,0,0,58]
+"group__aom__encoder.html#gad04799a74215e1b9609f7ccd1766f8c9":[12,1,0,0,37]
 };
