@@ -1,5 +1,14 @@
 var NAVTREEINDEX3 =
 {
+"group__cyclic__refresh.html#gafb17f1befe613fac6ceebb9b5b24ebd8":[12,2,9,3],
+"group__cyclic__refresh.html#gafc1304a44c092d497a6cbbbaef92d1b9":[12,2,9,10],
+"group__decoder.html":[12,0,0],
+"group__decoder.html#ga23378c7ca8c361c097181aaaa2a5a734":[12,0,0,4],
+"group__decoder.html#ga2544bac9fdc439f0effd6b1b14df54be":[12,0,0,10],
+"group__decoder.html#ga2b456cf67b1b64dabed370c5d7514b29":[12,0,0,11],
+"group__decoder.html#ga67b2d2d0bfa394bbbd1c5ce4876ed48c":[12,0,0,7],
+"group__decoder.html#ga9ee6dac1fc46ab5c254395eea5469d5d":[12,0,0,13],
+"group__decoder.html#gab03fdb999d1f83a5896869a3ba5f68f7":[12,0,0,12],
 "group__decoder.html#gab2bfd2f5517b9452d2c71b7c2b2e8e8d":[12,0,0,9],
 "group__decoder.html#gab456f6df8429a23dce32438f0a570ef6":[12,0,0,8],
 "group__decoder.html#gabd11df9f35d52ea76de2c8d32aa36963":[12,0,0,5],
@@ -94,32 +103,33 @@ var NAVTREEINDEX3 =
 "group__inter__mode__search.html#gae1aedf721583700393db3502d6042350":[12,2,3,1],
 "group__inter__mode__search.html#gaef5164626f2fbec0be2c3094fb13b079":[12,2,3,5],
 "group__intra__mode__search.html":[12,2,2],
-"group__intra__mode__search.html#ga1f6f374f792d71c79d53949a185799d6":[12,2,2,17],
-"group__intra__mode__search.html#ga3a03891b3b454db9c4446f779d3bfa44":[12,2,2,8],
-"group__intra__mode__search.html#ga3dba7f81ba3f8ca55df5dc98f871f8e8":[12,2,2,11],
+"group__intra__mode__search.html#ga1f6f374f792d71c79d53949a185799d6":[12,2,2,18],
+"group__intra__mode__search.html#ga3a03891b3b454db9c4446f779d3bfa44":[12,2,2,9],
+"group__intra__mode__search.html#ga3dba7f81ba3f8ca55df5dc98f871f8e8":[12,2,2,12],
 "group__intra__mode__search.html#ga46ac7127978a1310a85adc9a1e878668":[12,2,2,4],
 "group__intra__mode__search.html#ga520ae1e2beb80b7b069e71dc0c881f6f":[12,2,2,5],
-"group__intra__mode__search.html#ga54a3be2975508906034952fea34e6556":[12,2,2,14],
-"group__intra__mode__search.html#ga592fed21d73cb4034c0eca70da7fae1c":[12,2,2,13],
-"group__intra__mode__search.html#ga5c63552bf8f204e19cae7adfc6185b3a":[12,2,2,12],
-"group__intra__mode__search.html#ga5d1279f833651cdbb96966d83076f563":[12,2,2,6],
-"group__intra__mode__search.html#ga868a4e2cc95d1134e057ebf3a320c07a":[12,2,2,7],
-"group__intra__mode__search.html#ga888b8c7618a6df45a38e48f52e020ced":[12,2,2,16],
-"group__intra__mode__search.html#ga8f5e96e865ec83e37cb62fe69882a259":[12,2,2,9],
-"group__intra__mode__search.html#gab0adec0117540b9786dd57688c8020b0":[12,2,2,10],
+"group__intra__mode__search.html#ga54a3be2975508906034952fea34e6556":[12,2,2,15],
+"group__intra__mode__search.html#ga592fed21d73cb4034c0eca70da7fae1c":[12,2,2,14],
+"group__intra__mode__search.html#ga5c63552bf8f204e19cae7adfc6185b3a":[12,2,2,13],
+"group__intra__mode__search.html#ga5d1279f833651cdbb96966d83076f563":[12,2,2,7],
+"group__intra__mode__search.html#ga868a4e2cc95d1134e057ebf3a320c07a":[12,2,2,8],
+"group__intra__mode__search.html#ga888b8c7618a6df45a38e48f52e020ced":[12,2,2,17],
+"group__intra__mode__search.html#ga8f5e96e865ec83e37cb62fe69882a259":[12,2,2,10],
+"group__intra__mode__search.html#gab0adec0117540b9786dd57688c8020b0":[12,2,2,11],
+"group__intra__mode__search.html#gac3bbfdab84b3600422e2d77cc7dd62e8":[12,2,2,6],
 "group__intra__mode__search.html#gae234e4fbb4d2abad145f4353595fd8e6":[12,2,2,2],
 "group__intra__mode__search.html#gaf72915b72e91552643b40aa506ed426d":[12,2,2,3],
-"group__intra__mode__search.html#gafa28ef0b6fdbcde62d60ab5333944690":[12,2,2,15],
+"group__intra__mode__search.html#gafa28ef0b6fdbcde62d60ab5333944690":[12,2,2,16],
 "group__look__ahead__buffer.html":[12,2,0,5],
 "group__nonrd__mode__search.html":[12,2,12],
-"group__nonrd__mode__search.html#ga328360c35ea0f27804a7e649ea5d422a":[12,2,12,3],
-"group__nonrd__mode__search.html#ga5f86f14cbd08144d9201f7990ef88271":[12,2,12,5],
-"group__nonrd__mode__search.html#gaa980b8229e59638e72d3445c3014cc79":[12,2,12,2],
-"group__nonrd__mode__search.html#gab9d7783c6022c1366ea997e6c8bc5914":[12,2,12,8],
+"group__nonrd__mode__search.html#ga328360c35ea0f27804a7e649ea5d422a":[12,2,12,4],
+"group__nonrd__mode__search.html#ga3a61b19639ac3efe9d0ff860b0bc96fb":[12,2,12,8],
+"group__nonrd__mode__search.html#ga511634680c0fb42d578b7949592d7ff8":[12,2,12,7],
+"group__nonrd__mode__search.html#ga7c3da29aa38fb05510d2499aee49ea70":[12,2,12,5],
+"group__nonrd__mode__search.html#gaa980b8229e59638e72d3445c3014cc79":[12,2,12,3],
 "group__nonrd__mode__search.html#gabaa9801201975d4288732eea8ef24851":[12,2,12,1],
-"group__nonrd__mode__search.html#gac73009a89c66c664750636626bc9452f":[12,2,12,4],
+"group__nonrd__mode__search.html#gac73009a89c66c664750636626bc9452f":[12,2,12,2],
 "group__nonrd__mode__search.html#gac99f0993e853863177432a90cd83d5c7":[12,2,12,6],
-"group__nonrd__mode__search.html#gad98509bf6e54b930861ef1df4d0b310e":[12,2,12,7],
 "group__nonrd__mode__search.html#gafa44920244086ceee2883b80341c61d8":[12,2,12,0],
 "group__palette__mode__search.html":[12,2,2,0],
 "group__palette__mode__search.html#ga0865030d0ffa042390ab2472e77f957d":[12,2,2,0,0],
@@ -128,24 +138,25 @@ var NAVTREEINDEX3 =
 "group__palette__mode__search.html#ga499204b04894f62208ecd7481fd837ac":[12,2,2,0,2],
 "group__palette__mode__search.html#ga4c2ba8b9ea7370f75f364481f0aec9a3":[12,2,2,0,1],
 "group__palette__mode__search.html#ga5a3719d514a1fc927159d4af8f98f11c":[12,2,2,0,7],
+"group__palette__mode__search.html#ga61d1268829ad46968d16161466ac3b76":[12,2,2,0,9],
 "group__palette__mode__search.html#ga79e23cb5955092ba04bee379e97df918":[12,2,2,0,8],
 "group__palette__mode__search.html#gaa6a39d9de82e0e5cd963473067334e17":[12,2,2,0,4],
 "group__palette__mode__search.html#gab9bf846634be27493a882c390fd7bc55":[12,2,2,0,6],
-"group__palette__mode__search.html#gaea1f7a58c572de818564b309cf7c70e7":[12,2,2,0,9],
 "group__partition__search.html":[12,2,1],
-"group__partition__search.html#ga0664c147707f2d528d53cc09a7f41e20":[12,2,1,6],
-"group__partition__search.html#ga0d32a492481d81049254d362c3046d41":[12,2,1,2],
-"group__partition__search.html#ga2814000c23d084a5383f7c3669a40ec9":[12,2,1,5],
-"group__partition__search.html#ga73c2560dd156bd6a45160560ebfb16be":[12,2,1,8],
-"group__partition__search.html#ga825d23c65039a06658b783f641e4a369":[12,2,1,3],
-"group__partition__search.html#ga858f2a8955459b256a13fca734fc0948":[12,2,1,11],
-"group__partition__search.html#gab6ca7ecb046b0c7075bd7f3ca164b62a":[12,2,1,9],
-"group__partition__search.html#gac6ea78cef9b97053a93796b938d2a5a5":[12,2,1,12],
-"group__partition__search.html#gac96008483cc973bc1103cf990f7bbbee":[12,2,1,4],
-"group__partition__search.html#gacd50475d70739c9fa890e05d540cbca0":[12,2,1,0],
-"group__partition__search.html#gace5a349e10791d33edaaabf1fea7a839":[12,2,1,7],
+"group__partition__search.html#ga0664c147707f2d528d53cc09a7f41e20":[12,2,1,7],
+"group__partition__search.html#ga0940fd8dd7d0e3fddb48cdec3426e03f":[12,2,1,2],
+"group__partition__search.html#ga0d32a492481d81049254d362c3046d41":[12,2,1,3],
+"group__partition__search.html#ga2814000c23d084a5383f7c3669a40ec9":[12,2,1,6],
+"group__partition__search.html#ga382ec1672864ff96416a04a4a4f91944":[12,2,1,0],
+"group__partition__search.html#ga73c2560dd156bd6a45160560ebfb16be":[12,2,1,9],
+"group__partition__search.html#ga825d23c65039a06658b783f641e4a369":[12,2,1,4],
+"group__partition__search.html#ga858f2a8955459b256a13fca734fc0948":[12,2,1,12],
+"group__partition__search.html#gab6ca7ecb046b0c7075bd7f3ca164b62a":[12,2,1,10],
+"group__partition__search.html#gac6ea78cef9b97053a93796b938d2a5a5":[12,2,1,13],
+"group__partition__search.html#gac96008483cc973bc1103cf990f7bbbee":[12,2,1,5],
+"group__partition__search.html#gace5a349e10791d33edaaabf1fea7a839":[12,2,1,8],
 "group__partition__search.html#gacf0e64a22f62c95a3f8512f1cf0ec716":[12,2,1,1],
-"group__partition__search.html#gad9561a1da5a2377a8fa76435c8facef2":[12,2,1,10],
+"group__partition__search.html#gad9561a1da5a2377a8fa76435c8facef2":[12,2,1,11],
 "group__rate__control.html":[12,2,0,2],
 "group__rate__control.html#ga05ee091c593e5672c6be2d0bdd89d1cb":[12,2,0,2,4],
 "group__rate__control.html#ga06eb20a95903f261d8e9a86f6a359927":[12,2,0,2,25],
@@ -153,6 +164,7 @@ var NAVTREEINDEX3 =
 "group__rate__control.html#ga174d96c77a72a090d5e218346a91d4c2":[12,2,0,2,31],
 "group__rate__control.html#ga1930a02e62c42b75313b987806837c84":[12,2,0,2,5],
 "group__rate__control.html#ga1f1b566e7234deb8018a0bd3dc3822d7":[12,2,0,2,1],
+"group__rate__control.html#ga23765f9ab795ae26c6949163ceb9a4e3":[12,2,0,2,28],
 "group__rate__control.html#ga2739ae83fcd1266a2b44aae1ee40e57f":[12,2,0,2,17],
 "group__rate__control.html#ga2a0f590eb2dc358f9781654644a2519d":[12,2,0,2,8],
 "group__rate__control.html#ga2c30e6d5b7f0c87a7aa61cabace6905c":[12,2,0,2,13],
@@ -182,10 +194,9 @@ var NAVTREEINDEX3 =
 "group__rate__control.html#gacff14724140f9a2419bc82ef61ef2845":[12,2,0,2,30],
 "group__rate__control.html#gad9722dabdd6c62b9d2fac0551b83fe89":[12,2,0,2,20],
 "group__rate__control.html#gadfe05128d22bba397120763fe132c867":[12,2,0,2,6],
+"group__rate__control.html#gae256aad9cb7fbcb22b6944d5b3053a1f":[12,2,0,2,18],
 "group__rate__control.html#gae79c4d7e1bb558a1c2b4cd9da69b77c7":[12,2,0,2,35],
-"group__rate__control.html#gae9e6431ebd75ca58a1e526f91cc0cea8":[12,2,0,2,18],
 "group__rate__control.html#gae9eddc0e6469d28bd0429c03efe97544":[12,2,0,2,14],
-"group__rate__control.html#gaf4845f52af8f34c200706e1c3e14614f":[12,2,0,2,28],
 "group__rate__control.html#gaf73c75a80818ad2b556f6d86a7e71c5f":[12,2,0,2,15],
 "group__speed__features.html":[12,2,0,0],
 "group__speed__features.html#ga375df45f353341a53823feb529182b2a":[12,2,0,0,0],
@@ -222,15 +233,15 @@ var NAVTREEINDEX3 =
 "index.html#main_startpoints":[0,1],
 "index.html#main_support":[2],
 "intra__mode__search_8h.html":[14,0,2,2,8],
-"intra__mode__search_8h.html#a36fe8942d46efb604031987aef180df0":[14,0,2,2,8,6],
-"intra__mode__search_8h.html#aaf46284873fa449d7f843623a9e59c7f":[14,0,2,2,8,10],
-"intra__mode__search_8h.html#ac80bd25ae504f9dc621a5ced8a3e390f":[14,0,2,2,8,7],
-"intra__mode__search_8h.html#ac9f5640d9ece61cd6dbcda9f70fa68d8":[14,0,2,2,8,9],
-"intra__mode__search_8h.html#ade408273088bd18a20b290882c3d5da9":[14,0,2,2,8,8],
+"intra__mode__search_8h.html#a36fe8942d46efb604031987aef180df0":[14,0,2,2,8,7],
+"intra__mode__search_8h.html#aaf46284873fa449d7f843623a9e59c7f":[14,0,2,2,8,11],
+"intra__mode__search_8h.html#ac80bd25ae504f9dc621a5ced8a3e390f":[14,0,2,2,8,8],
+"intra__mode__search_8h.html#ac9f5640d9ece61cd6dbcda9f70fa68d8":[14,0,2,2,8,10],
+"intra__mode__search_8h.html#ade408273088bd18a20b290882c3d5da9":[14,0,2,2,8,9],
 "intra__mode__search_8h_source.html":[14,0,2,2,8],
 "intra__mode__search__utils_8h.html":[14,0,2,2,9],
 "intra__mode__search__utils_8h.html#a3f5fd5a4ab169294e490310fbc930617":[14,0,2,2,9,1],
-"intra__mode__search__utils_8h.html#a5ae6f76f06bf24048b936cd1ed709632":[14,0,2,2,9,0],
+"intra__mode__search__utils_8h.html#ada17eb3ace47aa1bf1542bf81835c877":[14,0,2,2,9,0],
 "intra__mode__search__utils_8h_source.html":[14,0,2,2,9],
 "lookahead_8h.html":[14,0,2,2,10],
 "lookahead_8h.html#a057e2ff7a73b405643340cb1d5564653":[14,0,2,2,10,2],
@@ -238,16 +249,5 @@ var NAVTREEINDEX3 =
 "lookahead_8h.html#a29315ad0754642cf92f547a36aa286b4":[14,0,2,2,10,0],
 "lookahead_8h.html#a36c0cd8514867cf37679891107355720":[14,0,2,2,10,4],
 "lookahead_8h.html#a442c559043280bd477c84f988af1c91f":[14,0,2,2,10,5],
-"lookahead_8h.html#aa177b3848c3b2d840eeb7060e5f163dd":[14,0,2,2,10,6],
-"lookahead_8h.html#af061d48eaecd02d50cf646e84426aca1":[14,0,2,2,10,1],
-"lookahead_8h_source.html":[14,0,2,2,10],
-"modules.html":[12],
-"pages.html":[],
-"palette_8h.html":[14,0,2,2,11],
-"palette_8h.html#a4a74357844cac7dba9020e29c704da37":[14,0,2,2,11,9],
-"palette_8h_source.html":[14,0,2,2,11],
-"partition__search_8h_source.html":[14,0,2,2,12],
-"pass2__strategy_8h_source.html":[14,0,2,2,13],
-"pickcdef_8h_source.html":[14,0,2,2,14],
-"picklpf_8h_source.html":[14,0,2,2,15]
+"lookahead_8h.html#aa177b3848c3b2d840eeb7060e5f163dd":[14,0,2,2,10,6]
 };
